from sklearn.base import BaseEstimator, TransformerMixin
import sklearn


class ProbT(BaseEstimator, TransformerMixin):
    """Wraps a sklearn classifier (ClassifierMixin) to use the output
    of their .predict_proba method.

    Parameters:
    -----------
    model : sklearn.base.ClassifierMixin
        A sklearn classification model

    drop : bool
        Flag if to drop the column with the 0 probabilties
    """
    def __init__(self,
                 model: sklearn.base.ClassifierMixin,
                 drop: bool = True):
        self.model = model
        self.drop = drop

    def fit(self, *args, **kwargs):
        self.model.fit(*args, **kwargs)
        return self

    def transform(self, X, **transform_params):
        Z = self.model.predict_proba(X)
        if self.drop:
            return Z[:, 1:]
        else:
            return Z



import pipelinetweak
import sklearn.pipeline
import sklearn.datasets
import sklearn.linear_model
import sklearn.dummy
import numpy as np


def test1():
    # load dataset
    tmp = sklearn.datasets.load_diabetes()
    y = tmp.target
    X = tmp.data

    # Regressor as transformer
    pipe = sklearn.pipeline.Pipeline(steps=[
        ('trans', pipelinetweak.PredT(
            sklearn.linear_model.LinearRegression())),
        ('pred', sklearn.dummy.DummyRegressor())
    ])
    # fit and predict
    pipe.fit(X, y)
    y_pred = pipe.predict(X)
    # compare
    target = [
        152.13348416, 152.13348416, 152.13348416, 152.13348416, 152.13348416]
    np.testing.assert_allclose(y_pred[:5], target)



from sklearn.base import BaseEstimator, TransformerMixin


class PredT(BaseEstimator, TransformerMixin):
    """Wraps a sklearn estimator (ClusterMixin, ClassifierMixin,
    RegressorMixin) to use the output of their .predict method
    as .transform output
    """
    def __init__(self, model):
        self.model = model

    def fit(self, *args, **kwargs):
        self.model.fit(*args, **kwargs)
        return self

    def transform(self, X, **transform_params):
        Z = self.model.predict(X)
        return Z.reshape(-1, 1) if len(Z.shape) == 1 else Z



from setuptools import setup


def read(fname):
    import os
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


setup(name='pipelinetweak',
      version='0.2.0',
      description='additional wrapper and classes for sklearn\' pipeline API',
      #long_description=read('README.md'),
      #long_description_content_type='text/markdown',
      url='http://github.com/kmedian/pipelinetweak',
      author='Ulf Hamster',
      author_email='554c46@gmail.com',
      license='MIT',
      packages=['pipelinetweak'],
      install_requires=[
          'setuptools>=40.0.0',
          'scikit-learn>=0.21.*'],
      python_requires='>=3.6',
      zip_safe=False)
